<?php
/**
 * Sample implementation of the Custom Header feature
 * http://codex.wordpress.org/Custom_Headers
 *
 * You can add an optional custom header image to header.php like so ...

	<?php $header_image = get_header_image();
	if ( ! empty( $header_image ) ) { ?>
		<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home">
			<img src="<?php header_image(); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="">
		</a>
	<?php } // if ( ! empty( $header_image ) ) ?>

 *
 * @package spd2014
 */

/**
 * Setup the WordPress core custom header feature.
 *
 * @uses spd2014_header_style()
 * @uses spd2014_admin_header_style()
 * @uses spd2014_admin_header_image()
 *
 * @package spd2014
 */
function spd2014_custom_header_setup() {
	if ( function_exists( 'add_theme_support' ) ) {
		add_theme_support( 'custom-header', apply_filters( 'spd2014_custom_header_args', array(
			'default-image'          => '',
			'default-text-color'     => 'fff',
			'width'                  => 1300,
			'height'                 => 200,
			'flex-height'            => true,
			'wp-head-callback'       => 'spd2014_header_style',
			'admin-head-callback'    => 'spd2014_admin_header_style',
			'admin-preview-callback' => 'spd2014_admin_header_image',
		) ) );
	}
}
add_action( 'after_setup_theme', 'spd2014_custom_header_setup' );

if ( ! function_exists( 'spd2014_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @see spd2014_custom_header_setup().
 */
function spd2014_header_style() {
	$header_text_color = get_header_textcolor();

	// If no custom options for text are set, let's bail
	// get_header_textcolor() options: HEADER_TEXTCOLOR is default, hide text (returns 'blank') or any hex value
	if ( HEADER_TEXTCOLOR == $header_text_color )
		return;

	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( 'blank' == $header_text_color ) :
	?>
		.site-title,
		.site-description {
			position: absolute;
			clip: rect(1px, 1px, 1px, 1px);
		}
	<?php
		// If the user has set a custom color for the text use that
		else :
	?>
		.site-header-title h1 a,
		.site-header-title h2 {
			color: #<?php echo $header_text_color; ?>;
		}
	<?php endif; ?>
	</style>
	<?php
}
endif; // spd2014_header_style

if ( ! function_exists( 'spd2014_admin_header_style' ) ) :
/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 *
 * @see spd2014_custom_header_setup().
 */
function spd2014_admin_header_style() {
	$header_image = get_header_image();
?>
<style type="text/css">

.site-header-title {
	padding-top: 1em;
	padding-left: 2em;
}

.site-header-inner {
	min-height: 200px;
	background-repeat: no-repeat;
}

.site-header-title h1 {
	font-size: 3em;
	text-shadow: 2px 2px 1px rgba(0,0,0,0.5);
}
.site-header-title h1 a:active,
.site-header-title h1 a:hover {
	text-decoration: none;
}

.site-header-title h2 {
	margin-top: 0em;
	font-size: 1.5em;
	text-shadow: 2px 2px 1px rgba(0,0,0,0.5);
}

	<?php if ( ! empty( $header_image ) ) { ?> .site-header-inner { background-image: url(<?php header_image(); ?>); }  <?php } ?>
</style>

<?php
}
endif; // spd2014_admin_header_style

if ( ! function_exists( 'spd2014_admin_header_image' ) ) :
/**
 * Custom header image markup displayed on the Appearance > Header admin panel.
 *
 * @see spd2014_custom_header_setup().
 */
function spd2014_admin_header_image() {
$style = sprintf( ' style="color:#%s; text-decoration: none;"', get_header_textcolor() );
?>	<div class="site-header-inner">
		<div class="site-header-title">
			<h1 class="site-title"><a onclick="return false;" <?php echo $style; ?> href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
			<h2 class="site-description" <?php echo $style; ?>><?php bloginfo( 'description' ); ?></h2>
		</div>						
	</div> <?php						
}
endif; // spd2014_admin_header_image

